@@ -3,7 +3,7 @@
    Copyright (C) 2020-2022 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 6.0.1 (2022-05-28)
+   Version: 6.2.0 (2022-07-09))
    Website: http://www.gingerblue.org/
 
  */
@@ -13,7 +13,6 @@
 #include <glib/gi18n.h>
 #include <gst/gst.h>
 #include <gst/player/player.h>
-#include <gst/tag/tag.h>
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
@@ -88,6 +87,7 @@ static void gb_assistant_button_clicked(GtkButton * button,
 	gchar *filename = NULL;
 	GDateTime *datestamp = g_date_time_new_now_utc ();
 	GstElementFactory *factory;
+	GTimeVal *timeval;
 	gst_element_send_event(recorder, gst_event_new_eos());
 	recorder = gst_pipeline_new("record_pipe");
 	/*
@@ -122,26 +122,16 @@ static void gb_assistant_button_clicked(GtkButton * button,
 	gst_bin_add_many(GST_BIN(recorder), src, conv, enc, muxer, sink, NULL);
 	gst_element_link_many(src, conv, enc, muxer, sink, NULL);
 	gst_element_set_state(recorder, GST_STATE_PLAYING);
-	tag_list = gst_tag_list_new (GST_TAG_ARTIST, gtk_entry_get_text(GTK_ENTRY(musician_entry)), NULL);
-	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
-	tag_list = gst_tag_list_new (GST_TAG_ALBUM, gtk_entry_get_text(GTK_ENTRY(album_entry)), NULL);
-	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
-	tag_list = gst_tag_list_new (GST_TAG_TITLE, gtk_entry_get_text(GTK_ENTRY(song_entry)), NULL);
-	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
-	tag_list = gst_tag_list_new (GST_TAG_COPYRIGHT, gtk_entry_get_text(GTK_ENTRY(label_entry)), NULL);
-	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
-	tag_list = gst_tag_list_new (GST_TAG_PUBLISHER, gtk_entry_get_text(GTK_ENTRY(label_entry)), NULL);
-	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
-	tag_list = gst_tag_list_new (GST_TAG_DATE_TIME, datestamp, NULL);
-	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
-	gst_vorbis_tag_add (tag_list, GST_TAG_ARTIST, gtk_entry_get_text(GTK_ENTRY(musician_entry)));
-	gst_vorbis_tag_add (tag_list, GST_TAG_ALBUM, gtk_entry_get_text(GTK_ENTRY(song_entry)));
-	gst_vorbis_tag_add (tag_list, GST_TAG_TITLE, gtk_entry_get_text(GTK_ENTRY(song_entry)));
-	gst_vorbis_tag_add (tag_list, GST_TAG_COPYRIGHT, gtk_entry_get_text(GTK_ENTRY(label_entry)));
-	gst_vorbis_tag_add (tag_list, GST_TAG_PUBLISHER, gtk_entry_get_text(GTK_ENTRY(label_entry)));
-	gst_vorbis_tag_add (tag_list, GST_TAG_DATE_TIME, datestamp);
-	gst_vorbis_tag_add (tag_list, GST_TAG_DATE_TIME, datestamp);
-	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
+	datestamp = g_date_time_new_now_utc ();
+        gst_tag_setter_add_tags (GST_TAG_SETTER (enc),
+                                 GST_TAG_MERGE_APPEND,
+                                 GST_TAG_TITLE, g_get_real_name(),
+                                 GST_TAG_ARTIST, g_get_real_name(),
+                                 GST_TAG_ALBUM, "Voicegram",
+                                 GST_TAG_COMMENT, "GNOME 43",
+                                 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
+                                 NULL);
+	g_date_time_unref (datestamp);
 	main_loops = g_main_loop_new(NULL, TRUE);
 	g_main_loop_run(main_loops);
 	gst_element_set_state(recorder, GST_STATE_NULL);
@@ -328,10 +318,9 @@ int main(int argc, char **argv)
 	recording_label = gtk_button_new_with_label("Recording");
 	recording_entry = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(recording_entry), g_strconcat(g_get_user_special_dir
-				     (G_USER_DIRECTORY_MUSIC), "/",
-				     gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
-				     gtk_entry_get_text(GTK_ENTRY(song_entry)),
-								   ".ogg", NULL));
+								   (G_USER_DIRECTORY_MUSIC), "/",
+								   gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+								   gtk_entry_get_text(GTK_ENTRY(song_entry)), ".ogg", NULL));
 	g_signal_connect(G_OBJECT(recording_label), "clicked",
 			 G_CALLBACK(gb_record_cb),
 			 g_strconcat(g_get_user_special_dir
@@ -341,8 +330,9 @@ int main(int argc, char **argv)
 				     ".ogg", NULL));
 	page[7].widget = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(page[7].widget), g_strconcat(g_get_user_special_dir
-								   (G_USER_DIRECTORY_MUSIC), "/",
-								  gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_", gtk_entry_get_text(GTK_ENTRY(song_entry)), ".ogg", NULL));
+								  (G_USER_DIRECTORY_MUSIC), "/",
+								  gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+								  gtk_entry_get_text(GTK_ENTRY(song_entry)), ".ogg", NULL));
 	gtk_box_pack_start(GTK_BOX(page[7].widget), GTK_WIDGET(recording_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[7].widget), GTK_WIDGET(recording_entry),
@@ -386,7 +376,9 @@ int main(int argc, char **argv)
 	g_signal_connect(G_OBJECT(stream_entry), "clicked",
 			 G_CALLBACK(gb_assistant_apply),
 		         gtk_entry_get_text(GTK_ENTRY(stream_entry)));
-	page[10].widget = gtk_label_new(g_strconcat("You can now upload the recorded Ogg Vorbis file to your account on SoundCloud, Bandcamp or Wordpress:\n\n", gtk_entry_get_text(GTK_ENTRY(recording_entry)), NULL));
+	gchar *record_attachment = g_strconcat(gtk_entry_get_text(GTK_ENTRY(recording_entry)), NULL);
+	gchar *subject = g_strconcat("[", gtk_entry_get_text(GTK_ENTRY(recording_entry)), "] ", gtk_entry_get_text(GTK_ENTRY(musician_entry)), " - ", gtk_entry_get_text(GTK_ENTRY(song_entry)), NULL);
+	page[10].widget = gtk_link_button_new_with_label (g_strconcat("mailto:\?attach=", record_attachment, NULL), "Compose email in Evolution with Ogg Vorbis Recording as attachment");
 	gtk_entry_set_text(GTK_ENTRY(page[10].widget), "Click Apply");
 	g_signal_connect (GTK_BUTTON(stream_entry), "clicked", G_CALLBACK(gb_assistant_apply), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
 	g_signal_connect(G_OBJECT(stream_label), "clicked",
@@ -470,13 +462,8 @@ int main(int argc, char **argv)
 	/*                                   NULL); */
 	/* gtk_assistant_commit (introduction); */
 	gtk_widget_show_all(GTK_WIDGET(introduction));
-	/* FIXME Fix core dump
-	   main_window = gingerblue_main_loop (data);
-	   gtk_widget_show_all (main_window);
-	 */
 	gst_init(&argc, &argv);
 	gst_init(NULL, NULL);
-
 	pipeline = gst_pipeline_new("record_pipe");
 
 	src = gst_element_factory_make("autoaudiosrc", "auto_source");
@@ -499,6 +486,32 @@ int main(int argc, char **argv)
 
 	gst_element_set_state(pipeline, GST_STATE_PLAYING);
 
+	xspf = fopen(g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(GTK_ENTRY(label_entry)), ".xspf", NULL), "w+");
+	fprintf(xspf, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
+	fprintf(xspf, "<playlist version=\"1\" xmlns=\"http://xspf.org/ns/0/\">\n");
+	fprintf(xspf, "<trackList>\n");
+	fprintf(xspf, "<track>\n");
+	fprintf(xspf, "%s", g_strconcat("<title>", gtk_entry_get_text(GTK_ENTRY(song_entry)), "</title>\n", NULL));
+	fprintf(xspf, "%s", g_strconcat("<location>file://", gtk_entry_get_text(GTK_ENTRY(computer_entry)), "/", gtk_entry_get_text(GTK_ENTRY(recording_entry)), "</location>\n", NULL));
+	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/version'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), VERSION);
+	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/musician'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(musician_entry)));
+	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/song'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(song_entry)));
+	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/instrument'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(instrument_entry)));
+	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/line'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(line_entry)));
+	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/label'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(label_entry)));
+	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/station'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(computer_entry)));
+	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/filename'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(recording_entry)));
+	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/album'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(album_entry)));
+	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/studio'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+	fprintf(xspf, "</track>\n");
+	fprintf(xspf, "</trackList>\n");
+	fprintf(xspf, "</playlist>\n");
+	fclose(xspf);
+
+	gtk_widget_set_size_request(GTK_WIDGET(window), 800, 600);
+	gtk_window_set_title (GTK_WINDOW (window), g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(GTK_ENTRY(label_entry)), ".xspf", NULL));
+	gtk_widget_show_all (GTK_WIDGET(window));
+
 	main_loops = g_main_loop_new(NULL, TRUE);
 	g_main_loop_run(main_loops);
 
@@ -521,19 +534,6 @@ int main(int argc, char **argv)
 	/* g_free (gingerblue_data); */
 
 	g_date_time_unref (datestamp);
-
-	xspf = fopen(g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(GTK_ENTRY(label_entry)), ".xspf", NULL), "w+");
-	fprintf(xspf, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
-	fprintf(xspf, "<playlist version=\"1\" xmlns=\"http://xspf.org/ns/0/\">\n");
-	fprintf(xspf, "<trackList>\n");
-	fprintf(xspf, "<track>\n");
-	fprintf(xspf, "%s", g_strconcat("<title>", gtk_entry_get_text(GTK_ENTRY(song_entry)), "</title>\n", NULL));
-	fprintf(xspf, "%s", g_strconcat("<location>file://", gtk_entry_get_text(GTK_ENTRY(computer_entry)), "/", gtk_entry_get_text(GTK_ENTRY(recording_entry)), "</location>\n", NULL));
-	fprintf(xspf, "</track>\n");
-	fprintf(xspf, "</trackList>\n");
-	fprintf(xspf, "</playlist>\n");
-	fclose(xspf);
-
 	gtk_main();
 	return (0);
 }
