@@ -1,6 +1,3 @@
-#ifndef _GINGERBLUE_STORAGE_H_
-#define _GINGERBLUE_STORAGE_H_ 1
-
 #define GINGERBLUE_STORAGE 2000
 
 typedef struct _GingerblueStorage {
@@ -9,5 +6,3 @@ typedef struct _GingerblueStorage {
 } GingerblueStorage;
 
 void gingerblue_storage_set(GingerblueStorage *storage, int storage_allocated, int storagemap);
-
-#endif /* _GINGERBLUE_STORAGE_H_ */
